@@ -51,10 +51,10 @@
             (rdf_meta)/1,               % +Heads
             op(1150, fx, (rdf_meta))
           ]).
-:- use_module(library(error)).
-:- use_module(library(lists)).
-:- use_module(library(option)).
-:- use_module(library(pairs)).
+:- autoload(library(error),[must_be/2,existence_error/2]).
+:- autoload(library(lists),[member/2]).
+:- autoload(library(option),[option/3]).
+:- autoload(library(pairs),[map_list_to_pairs/3,pairs_values/2]).
 
 :- meta_predicate
     rdf_current_prefix(:, -),
@@ -180,7 +180,7 @@ rdf_db:ns(xsd,     'http://www.w3.org/2001/XMLSchema#').
 %   Register Prefix as an abbreviation for URI. Options:
 %
 %           * force(Boolean)
-%           If =true=, Replace existing namespace alias. Please note
+%           If =true=, replace existing namespace alias. Please note
 %           that replacing a namespace is dangerous as namespaces
 %           affect preprocessing. Make sure all code that depends on
 %           a namespace is compiled after changing the registration.
@@ -267,7 +267,7 @@ rdf_unregister_prefix(Alias) :-
 
 %!  rdf_current_ns(:Prefix, ?URI) is nondet.
 %
-%   @deprecated.  Use rdf_current_prefix/2.
+%   @deprecated  Use rdf_current_prefix/2.
 
 rdf_current_ns(Prefix, URI) :-
     rdf_current_prefix(Prefix, URI).
@@ -277,7 +277,7 @@ rdf_current_ns(Prefix, URI) :-
 %
 %   Register an RDF prefix.
 %
-%   @deprecated. Use rdf_register_prefix/2 or rdf_register_prefix/3.
+%   @deprecated  Use rdf_register_prefix/2 or rdf_register_prefix/3.
 
 rdf_register_ns(Prefix, URI) :-
     rdf_register_prefix(Prefix, URI).
@@ -580,11 +580,23 @@ system:goal_expansion(G, Expanded) :-
     rdf_meta_specification(G, IM, Spec),
     rdf_expand(G, Spec, Expanded, LM).
 
+system:term_expansion(Module:Fact, Expanded) :-
+    atom(Module),
+    rdf_meta_specification(Fact, Module, Spec),
+    rdf_expand(Fact, Spec, ExpandedFact, Module),
+    Fact \== ExpandedFact,
+    Expanded = (Module:ExpandedFact).
 system:term_expansion(Fact, Expanded) :-
     prolog_load_context(module, Module),
     rdf_meta_specification(Fact, Module, Spec),
     rdf_expand(Fact, Spec, Expanded, Module),
     Fact \== Expanded.
+system:term_expansion((Module:Head :- Body), (Expanded :- Body)) :-
+    atom(Module),
+    rdf_meta_specification(Head, Module, Spec),
+    rdf_expand(Head, Spec, ExpandedHead, Module),
+    Head \== ExpandedHead,
+    Expanded = (Module:ExpandedHead).
 system:term_expansion((Head :- Body), (Expanded :- Body)) :-
     prolog_load_context(module, Module),
     rdf_meta_specification(Head, Module, Spec),
